@@ -43,7 +43,7 @@ associations between classes.
 use Carp qw/croak carp/;
 use Exporter::Lite;
 our @EXPORT
-    = qw(column type default literal validator autocompleted immutable unreadable max_length length distinct mandatory not_null sort_order valid_values label hints render_as render since input_filters output_filters filters virtual is as by are on schema indexed valid order);
+    = qw(column type default literal validator autocompleted immutable unreadable max_length length distinct mandatory not_null sort_order valid_values label hints render_as render since till input_filters output_filters filters virtual is as by are on schema indexed valid order);
 
 our $SCHEMA;
 our $SORT_ORDERS = {};
@@ -103,7 +103,7 @@ sub column {
     my $name = lc(shift);
 
     my $from = (caller)[0];
-    if ($from =~ s/::Schema$//) {
+    if ($from =~ s/::Schema$// && $from !~ /Script/) {
         no strict 'refs';
 
         carp << "." unless $from->{_seen_column_warning}++;
@@ -477,6 +477,17 @@ sub since {
     _list( since => @_ );
 }
 
+=head2 till
+
+What application version this column was last supported.  Correct usage
+is C<till '0.2.5'>.
+
+=cut
+
+sub till {
+    _list( till => @_ );
+}
+
 =head2 valid_values
 
 A list of valid values for this column. Jifty will use this to
